Changelog
=========


:Version: 1.0-rc.1 of 2017-09-25

Refactoring into the scorr module for public release in pip-installable form.


:Version: [unreleased] of 2009-03-06

The functions provided by scorr were part of a large personal tool collection 
for research. Development started after switching to Python and missing a 
*fast* equivalent to MATLAB's xcorr. Functionality was added over time as 
needed, finally three-point correlations in 2017.
